<?php

namespace Drupal\centreon_status\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\centreon_status\CentreonStatus;

/**
 * Provides route responses for the Example module.
 */
class CentreonController extends ControllerBase {

  /**
   * Service Status.
   *
   * @return array
   *   renderable array.
   */
  public function serviceStatus() {
    $header = [
      ['data' => t('State')],
      ['data' => t('Hostname')],
      ['data' => t('Services')],
      ['data' => t('Status information')],
    ];

    $result = CentreonStatus::getJson();
    $json = $result['services'];

    // Populate the rows.
    $rows = [];
    foreach ($json as $row) {

      switch ($row['current_state']) {
        case 0:
          $current_state = "OK";
          $class = "status_ok";
          break;

        case 1:
          $current_state = "Warning";
          $class = "status_warning";
          break;

        case 2:
          $current_state = "Critical";
          $class = "status_critical";
          break;

        case 3:
          $current_state = "Unknown";
          $class = "status_unknown";
          break;
      }

      $rows[] = [
        'data' => [
        [
          'data' => [
            '#markup' => '<span class="' . $class . ' badge_cenreon">' . $current_state . '</span>',
          ],
          'class' => 'tdcenter',
        ],
          'hostname' => $row['host_name'],
          'service' => $row['service_description'],
          'status information' => $row['plugin_output'],
        ],
      ];
    }

    // Generate the table.
    $build['config_table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => [
        'id' => ['centreon_status'],
      ],
    ];

    // Finally add the pager.
    $build['pager'] = [
      '#type' => 'pager',
    ];

    return $build;
  }

  /**
   * Hosts Status.
   *
   * @return array
   *   renderable array.
   */
  public function hostsStatus() {
    $header = [
      ['data' => t('State')],
      ['data' => t('Hostname')],
      ['data' => t('Status information')],
    ];

    $result = CentreonStatus::getJson();
    $json = $result['hosts'];

    // Populate the rows.
    $rows = [];
    foreach ($json as $row) {

      switch ($row['current_state']) {
        case 0:
          $current_state = "OK";
          $class = "status_ok";
          break;

        case 1:
          $current_state = "Warning";
          $class = "status_warning";
          break;

        case 2:
          $current_state = "Critical";
          $class = "status_critical";
          break;

        case 3:
          $current_state = "Unknown";
          $class = "status_unknown";
          break;
      }

      $rows[] = [
        'data' => [
        [
          'data' => [
            '#markup' => '<span class="' . $class . ' badge_cenreon">' . $current_state . '</span>',
          ],
          'class' => 'tdcenter',
        ],
          'hostname' => $row['host_name'],
          'status information' => $row['plugin_output'],
        ],
      ];
    }

    // Generate the table.
    $build['config_table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => [
        'id' => ['centreon_status'],
      ],
    ];

    // Finally add the pager.
    $build['pager'] = [
      '#type' => 'pager',
    ];

    return $build;
  }

}
